@@ -143,7 +143,7 @@ def list_azs():
 
     """
 
-    return boto3.client('ec2').describe_availability_zones().get('AvailabilityZones')
+    return get_ec2().describe_availability_zones().get('AvailabilityZones')
 
 
 ###########################################################################
@@ -1514,7 +1514,7 @@ def get_zone_vpc_ids(zone_id: str):
     :param id: The id of the hosted zone
     :return: a list of VPC id strings associated with that hosted zone
     """
-    vpcs = get_route53().get_hosted_zone(Id = zone_id).get('VPCs')
+    vpcs = get_route53().get_hosted_zone(Id = zone_id).get('VPCs', [])
     return [
       vpc.get('VPCId')
       for vpc in vpcs
