@@ -1,4 +1,4 @@
-from unittest import TestCase, mock
+from unittest import TestCase, mock, main
 from aws.iam import *
 from po.pretty_object import PrettyObject
 
@@ -42,3 +42,7 @@ class TestIam(TestCase):
 
         profile = get_profile('bogus')
         self.assertIsNone(profile)
+
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
